Django Lanthanum Documentation
==============================

Django Lanthanum allows you to add dynamic json schema fields to your Django models.

Contents:

.. toctree::
   :maxdepth: 2
   :name: Contents

   getting_started

